@@ -1,5 +1,5 @@
 createHeightmask <-
-function(dataset.height,dimension, shift, resolution=1){
+function(dataset.height, dimension, origin, resolution=1){
 	#create grid
 	height.matrix <- matrix(0,dimension[1],dimension[2])
 
@@ -10,11 +10,9 @@ function(dataset.height,dimension, shift, resolution=1){
 		lat <- dataset.height$lat
 		height <- dataset.height$height
 
-		#shift data to origin
-		long <- long - shift[1]
-		lat <- lat - shift[2]
-
 		#transformate coordinates to grid position
+		long <- long - origin[1]
+		lat <- lat - origin[2]
 		long <- round(long / resolution) 
 		lat <- round(lat / resolution)
 
@@ -30,3 +28,4 @@ function(dataset.height,dimension, shift, resolution=1){
 
 	return(height.matrix)
 }
+
