@@ -1,5 +1,5 @@
 data.into.Grid <-
-function(dataset.one.species, dimension, shift, resolution=1){
+function(dataset.one.species, dimension, origin, resolution=1){
 	#create grid
 	grid <- matrix(0,dimension[1],dimension[2])
 
@@ -8,9 +8,9 @@ function(dataset.one.species, dimension, shift, resolution=1){
 	lat <- dataset.one.species$lat
 
 
-	#shift coordinates to origin
-	long <- long - shift[1]
-	lat <- lat - shift[2]
+	#origin coordinates to origin
+	long <- long - origin[1]
+	lat <- lat - origin[2]
 
 	#transformate coordinates to grid position
 	long <- round(long / resolution) 
@@ -22,3 +22,4 @@ function(dataset.one.species, dimension, shift, resolution=1){
 	}
 	return(grid)
 }
+
